@@ -42,7 +42,7 @@ proc Mh_Preferences {} {
     Preferences_Add "MH Tweaks" \
 "Note that most of MH is parameterized by your [file tail $mhProfile(profile)] file.
 These options just affect a few things particular to exmh." [list \
-	{mhProfile(scan-proc) scanProc scan {Scan program}
+	{mhProfile(scan-proc) scanProc {scan -noheader} {Scan program}
 "If you have a custom scan program, name it here."} \
 	{mhProfile(sendType) sendType {CHOICE wait async xterm} {How to send messages}
 "There are three ways exmh can send a message for you:
@@ -312,9 +312,12 @@ proc Mh_AnnoEnviron { draftID } {
 }
 proc Mh_AnnoCleanup { draftID } {
     global exmh env
+    
     foreach key {mhannoforw mhannorepl mhannodist mhannotate mhdist
 		 mhaltmsg mhfolder mhmessages mhinplace folder action} {
-	catch {unset exmh($draftID,$key)}
+	if {[info exist exmh($draftID,$key)]} {
+	    unset exmh($draftID,$key)	;# Faster than catch-unset
+	}
 	if {[regexp ^mh $key]} {
 	    catch {unset env($key)}
 	}
