@@ -260,6 +260,14 @@ proc Sedit_Start { draft } {
 	}
     }
 }
+
+proc SeditBeautify { t } {
+    Msg_HighlightInit $t
+    set start [$t index "header + 1 line"]
+    set end   [$t index end]
+    Msg_TextHighlight $t $start $end
+}
+
 proc SeditSetContext { draft t } {
     # Called when menus are posted to set the context for some commands
     global sedit
@@ -497,6 +505,7 @@ proc SeditSendOnly { draft t } {
 	    if {$async == "async"} {
 		set mhProfile(sendType) "wait"
 	    }
+            set action $exmh($id,action)
 	}
 	SeditMsg $t "Sending message..."
 	SeditMarkSent $t
@@ -507,6 +516,7 @@ proc SeditSendOnly { draft t } {
 	if {! $sedit($t,keep)} {
 	    SeditNuke $draft $t
 	} else {
+            set exmh($id,action) $action
 	    SeditSave $draft $t		;# Restore draft deleted by MH
 	    set mhProfile(sendasync) $async
 	    $sedit($t,toplevel).but.send config -state normal
