@@ -156,7 +156,7 @@ proc URI_StartViewer {xuri} {
     string trimright $xuri "."
 
     if [regexp {^mailto:(.*)$} $xuri x address] {
-	Sedit_Mailto $xuri
+	Msg_Mailto $xuri
 	return
     }
     regsub -all {[][$\\,~ ]} $xuri {[scan \\& %c x ; format "%%%02x" $x]} xuri
